@@ -8,7 +8,7 @@ from abc import ABC, abstractmethod
 from typing import List
 
 from mlcvzoo_base.api.data.annotation import BaseAnnotation
-from mlcvzoo_base.data_preparation.AnnotationClassMapper import AnnotationClassMapper
+from mlcvzoo_base.api.data.annotation_class_mapper import AnnotationClassMapper
 
 
 class AnnotationParser(ABC):
