@@ -12,7 +12,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 
 import related
-from config_builder.BaseConfigClass import BaseConfigClass
+from config_builder import BaseConfigClass
 
 from mlcvzoo_base.api.configuration import (
     BaseDetectorConfig,
@@ -25,7 +25,7 @@ from mlcvzoo_base.api.configuration import (
 class DetectorConfig(BaseConfigClass, BaseDetectorConfig):
     """Class for parsing information about detector model"""
 
-    # NOTE: When the fields are empty, they be filled based on the given config-path filename
+    # NOTE: When the fields are empty, they are filled based on the given config-path filename
 
     MODEL_TYPE: str = related.StringField(default="")
     MODEL_VERSION: str = related.StringField(default="")
