@@ -6,7 +6,7 @@
 from typing import Optional
 
 import related
-from config_builder.BaseConfigClass import BaseConfigClass
+from config_builder import BaseConfigClass
 
 from mlcvzoo_base.configuration.structs import DeviceQueryTypes
 
@@ -21,5 +21,5 @@ class ModelTimerDeviceQueryConfig(BaseConfigClass):
         return (
             self.device_index is None
             or isinstance(self.device_index, int)
-            and self.query_type in [d.upper() for d in DeviceQueryTypes]  # type: ignore[attr-defined]
+            and self.query_type in [d.value.upper() for d in DeviceQueryTypes]
         )
