@@ -8,7 +8,7 @@ Module for configuring the visualization of model outputs
 """
 
 import related
-from config_builder.BaseConfigClass import BaseConfigClass
+from config_builder import BaseConfigClass
 
 
 @related.mutable(strict=True)
