@@ -145,6 +145,9 @@ class MOTAnnotationBuilder(AnnotationBuilder):
 
         bounding_boxes: List[BoundingBox] = []
 
+        if self.image_id not in self.annotation_line_dict:
+            return bounding_boxes
+
         for mot_annotation_line in self.annotation_line_dict[self.image_id]:
             # Note: annotation is given in a .txt file where each line equals to one bounding box.
             # These lines are contained in self.mot_annotations as a list of strings.
